==> fred-api-diagnostics-1.0.0.tar.gz: fred-api-diagnostics-1.0.0/setup.py <==
#!/usr/bin/python3
#
# Copyright (C) 2018-2019  CZ.NIC, z. s. p. o.
#
# This file is part of FRED.
#
# FRED is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# FRED is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with FRED.  If not, see <https://www.gnu.org/licenses/>.

"""Setup script for fred_api."""
import os
from datetime import date
from distutils.command.build import build
from distutils.command.sdist import sdist
from glob import glob

import pkg_resources
from setuptools import Command, find_namespace_packages, setup


class BuildGRPCProtos(Command):
    """Command to generate project *_pb2.py modules from proto files."""

    user_options = [
        ('build-lib=', 'd', 'directory to "build" (copy) to'),
    ]

    def initialize_options(self):
        self.build_lib = None
        self.proto_path = '.'
        self.output_path = '.'
        self.proto_files = []
        self.grpc_files = []

    def finalize_options(self):
        self.set_undefined_options('build', ('build_lib', 'build_lib'))

    def run(self):
        from grpc_tools.protoc import main as protoc_main

        includes = [self.proto_path, pkg_resources.resource_filename('grpc_tools', '_proto')]
        args = ['__main__']
        args += ['-I%s' % x for x in includes]

        # Generate protobuf modules
        print('building protos')
        for proto_file in self.proto_files:
            print('generating %s' % proto_file)
            protoc_main(args + ['--python_out', self.output_path, os.path.join(self.proto_path, proto_file)])

        # Generate grpc modules
        print('building grpc')
        for grpc_file in self.grpc_files:
            print('generating %s' % grpc_file)
            protoc_main(args + ['--grpc_python_out', self.output_path, os.path.join(self.proto_path, grpc_file)])


class CustomBuild(build):
    sub_commands = [('build_grpc', None)] + build.sub_commands


class CustomSdist(sdist):
    sub_commands = [('build_grpc', None)] + sdist.sub_commands


def readme():
    """Return content of README file."""
    with open(os.path.join(os.path.dirname(__file__), 'README.rst'), encoding='utf-8') as f:
        return f.read()


SETUP_REQUIRES = ['grpcio-tools<=1.26.0', 'grpcio<=1.26.0']
INSTALL_REQUIRES = ['grpcio', 'googleapis-common-protos']
VERSION = '1.0.0'


setup(
    name='fred-api-diagnostics',
    version=VERSION,
    description='Protocol buffers for FRED Diagnostics',
    long_description=readme(),
    author='Jan Musílek',
    author_email='jan.musilek@nic.cz',
    packages=find_namespace_packages(),
    include_package_data=True,
    python_requires='>=3.6',
    setup_requires=SETUP_REQUIRES,
    install_requires=INSTALL_REQUIRES,
    options={
        'build_grpc': {
            'proto_files': glob(os.path.join('fred_api', '**', '*.proto'), recursive=True),
            'grpc_files': glob(os.path.join('fred_api', '**', '*_grpc.proto'), recursive=True),
        }
    },
    cmdclass={
        'sdist': CustomSdist,
        'build': CustomBuild,
        'build_grpc': BuildGRPCProtos,
    },
    classifiers=[
      'Development Status :: 2 - Pre-Alpha',
      'Environment :: No Input/Output (Daemon)',
      'Intended Audience :: Developers',
      'Intended Audience :: Information Technology',
      'Intended Audience :: System Administrators',
      'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
      'Operating System :: OS Independent',
      'Programming Language :: Python',
      'Programming Language :: Python :: 3.5',
      'Programming Language :: Python :: 3.6',
      'Programming Language :: Python :: 3.7',
      'Programming Language :: Python :: 3.8',
      'Topic :: System :: Monitoring',
    ]
)

==> fred-api-diagnostics-1.0.1.tar.gz: fred-api-diagnostics-1.0.1/setup.py <==
#!/usr/bin/python3
#
# Copyright (C) 2018-2019  CZ.NIC, z. s. p. o.
#
# This file is part of FRED.
#
# FRED is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# FRED is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with FRED.  If not, see <https://www.gnu.org/licenses/>.

"""Setup script for fred_api."""
import os
from datetime import date
from distutils.command.build import build
from distutils.command.sdist import sdist
from glob import glob

import pkg_resources
from setuptools import Command, find_namespace_packages, setup


class BuildGRPCProtos(Command):
    """Command to generate project *_pb2.py modules from proto files."""

    user_options = [
        ('build-lib=', 'd', 'directory to "build" (copy) to'),
    ]

    def initialize_options(self):
        self.build_lib = None
        self.proto_path = '.'
        self.output_path = '.'
        self.proto_files = []
        self.grpc_files = []

    def finalize_options(self):
        self.set_undefined_options('build', ('build_lib', 'build_lib'))

    def run(self):
        from grpc_tools.protoc import main as protoc_main

        includes = [self.proto_path, pkg_resources.resource_filename('grpc_tools', '_proto')]
        args = ['__main__']
        args += ['-I%s' % x for x in includes]

        # Generate protobuf modules
        print('building protos')
        for proto_file in self.proto_files:
            print('generating %s' % proto_file)
            protoc_main(args + ['--python_out', self.output_path, os.path.join(self.proto_path, proto_file)])

        # Generate grpc modules
        print('building grpc')
        for grpc_file in self.grpc_files:
            print('generating %s' % grpc_file)
            protoc_main(args + ['--grpc_python_out', self.output_path, os.path.join(self.proto_path, grpc_file)])


class CustomBuild(build):
    sub_commands = [('build_grpc', None)] + build.sub_commands


class CustomSdist(sdist):
    sub_commands = [('build_grpc', None)] + sdist.sub_commands


def readme():
    """Return content of README file."""
    with open(os.path.join(os.path.dirname(__file__), 'README.rst'), encoding='utf-8') as f:
        return f.read()


SETUP_REQUIRES = ['grpcio-tools', 'grpcio']
INSTALL_REQUIRES = ['grpcio', 'googleapis-common-protos']
VERSION = '1.0.1'


setup(
    name='fred-api-diagnostics',
    version=VERSION,
    description='Protocol buffers for FRED Diagnostics',
    long_description=readme(),
    author='Jan Musílek',
    author_email='jan.musilek@nic.cz',
    packages=find_namespace_packages(),
    include_package_data=True,
    python_requires='>=3.6',
    setup_requires=SETUP_REQUIRES,
    install_requires=INSTALL_REQUIRES,
    options={
        'build_grpc': {
            'proto_files': glob(os.path.join('fred_api', '**', '*.proto'), recursive=True),
            'grpc_files': glob(os.path.join('fred_api', '**', '*_grpc.proto'), recursive=True),
        }
    },
    cmdclass={
        'sdist': CustomSdist,
        'build': CustomBuild,
        'build_grpc': BuildGRPCProtos,
    },
    classifiers=[
      'Development Status :: 2 - Pre-Alpha',
      'Environment :: No Input/Output (Daemon)',
      'Intended Audience :: Developers',
      'Intended Audience :: Information Technology',
      'Intended Audience :: System Administrators',
      'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
      'Operating System :: OS Independent',
      'Programming Language :: Python',
      'Programming Language :: Python :: 3.5',
      'Programming Language :: Python :: 3.6',
      'Programming Language :: Python :: 3.7',
      'Programming Language :: Python :: 3.8',
      'Topic :: System :: Monitoring',
    ]
)
